# -*- coding: utf-8 -*-
from django.http import JsonResponse
from djangoApiDec.djangoApiDec import queryString_required
from udicTfidf import TFIDF
from udic_nlp_API.settings_database import uri
obj = TFIDF(uri=uri)

@queryString_required(['keyword'])
def idf(request):
    keyword = request.GET['keyword']
    return JsonResponse(obj.idf(keyword), safe=False)

def tfidf(request):
    if request.POST and 'doc' in request.POST:
        doc = request.POST.dict()['doc']
        try:
            return JsonResponse(obj.tfidf(doc), safe=False)
        except ValueError as e:
            return JsonResponse([], safe=False)
    return JsonResponse([], safe=False)


# author: Shane Yu  date: April 8, 2017
from django.core.management.base import BaseCommand, CommandError
from udic_nlp_API.settings_database import uri
from udicTfidf import TFIDF

logging.basicConfig(format='%(levelname)s : %(asctime)s : %(message)s', filename='buildTfidf.log', level=logging.INFO)

class Command(BaseCommand):
    help = 'use this for build model of tfidf!'
    
    def add_arguments(self, parser):
        # Positional arguments
        parser.add_argument('--file', help='file that used to calculate idf', type=str, required=True)

    def handle(self, *args, **options):
        tfidf = TFIDF(uri)
        tfidf.build(options['file'])
        self.stdout.write(self.style.SUCCESS('build tfidf model success!!!'))


from distutils.core import setup

setup(
    name = 'udicTfidf',
    packages=['udicTfidf'],
    package_dir={'udicTfidf':'udicTfidf'},
    package_data={'udicTfidf':['management/commands/*']},
    version = '0.2',
    description = 'A django App for udicTfidf',
    author = ['davidtnfsh'],
    author_email = 'davidtnfsh@gmail.com',
    url = 'https://github.com/udicatnchu/tf-idf',
    download_url = 'https://github.com/udicatnchu/tf-idf',
    keywords = ['udicTfidf', 'tf-idf'],
    classifiers = [],
    license='GPL3.0',
    install_requires=[
        'sklearn',
        'numpy',
        'scipy',
        'pymongo',
        'udicOpenData',
        'jieba'
    ],
    zip_safe=True,
)
